@@ -548,7 +548,7 @@ oj_dump_xml_time(VALUE obj, Out out) {
         tzhour = (int)(tzsecs / 3600);
         tzmin = (int)(tzsecs / 60) - (tzhour * 60);
     }
-    if (0 == nsec || 0 == out->opts->sec_prec) {
+    if ((0 == nsec && !out->opts->sec_prec_set) || 0 == out->opts->sec_prec) {
 	if (0 == tzsecs && rb_funcall2(obj, oj_utcq_id, 0, 0)) {
 	    sprintf(buf, "%04d-%02d-%02dT%02d:%02d:%02dZ", ti.year, ti.mon, ti.day, ti.hour, ti.min, ti.sec);
 	    oj_dump_cstr(buf, 20, 0, 0, out);
@@ -1023,8 +1023,8 @@ oj_dump_fixnum(VALUE obj, int depth, Out out, bool as_ok) {
     int		neg = 0;
     bool	dump_as_string = false;
 
-    if (out->opts->integer_range_max != 0 && out->opts->integer_range_min != 0 &&
-	(out->opts->integer_range_max < num || out->opts->integer_range_min > num)) {
+    if (out->opts->int_range_max != 0 && out->opts->int_range_min != 0 &&
+	(out->opts->int_range_max < num || out->opts->int_range_min > num)) {
 	dump_as_string = true;
     }
     if (0 > num) {
@@ -1062,23 +1062,20 @@ void
 oj_dump_bignum(VALUE obj, int depth, Out out, bool as_ok) {
     volatile VALUE	rs = rb_big2str(obj, 10);
     int			cnt = (int)RSTRING_LEN(rs);
-	bool		dump_as_string = false;
+    bool		dump_as_string = false;
 
-	if (out->opts->integer_range_max != 0 || out->opts->integer_range_min != 0) { // Bignum cannot be inside of Fixnum range
+    if (out->opts->int_range_max != 0 || out->opts->int_range_min != 0) { // Bignum cannot be inside of Fixnum range
 	dump_as_string = true;
 	assure_size(out, cnt + 2);
 	*out->cur++ = '"';
-	} else {
+    } else {
 	assure_size(out, cnt);
-	}
-
+    }
     memcpy(out->cur, rb_string_value_ptr((VALUE*)&rs), cnt);
     out->cur += cnt;
-
-	if(dump_as_string) {
+    if (dump_as_string) {
 	*out->cur++ = '"';
-	}
-
+    }
     *out->cur = '\0';
 }
 
