@@ -3,8 +3,8 @@
  * All rights reserved.
  */
 
-#ifndef __OJ_DUMP_H__
-#define __OJ_DUMP_H__
+#ifndef OJ_DUMP_H
+#define OJ_DUMP_H
 
 #include <ruby.h>
 
@@ -45,6 +45,8 @@ extern void	oj_dump_rails_val(VALUE obj, int depth, Out out);
 extern void	oj_dump_custom_val(VALUE obj, int depth, Out out, bool as_ok);
 extern void	oj_dump_wab_val(VALUE obj, int depth, Out out);
 
+extern void	oj_dump_raw_json(VALUE obj, int depth, Out out);
+
 extern VALUE	oj_add_to_json(int argc, VALUE *argv, VALUE self);
 extern VALUE	oj_remove_to_json(int argc, VALUE *argv, VALUE self);
 
@@ -91,4 +93,4 @@ dump_ulong(unsigned long num, Out out) {
     *out->cur = '\0';
 }
 
-#endif /* __OJ_DUMP_H__ */
+#endif /* OJ_DUMP_H */
