@@ -56,7 +56,7 @@ dump_data(VALUE obj, int depth, Out out, bool as_ok) {
 	    }
 	} else {
 	    long	id = oj_check_circular(obj, out);
-	    
+
 	    if (0 <= id) {
 		dump_obj_attrs(obj, clas, id, depth, out);
 	    }
@@ -72,7 +72,7 @@ dump_obj(VALUE obj, int depth, Out out, bool as_ok) {
 	volatile VALUE	rstr = rb_funcall(obj, oj_to_s_id, 0);
 	const char	*str = rb_string_value_ptr((VALUE*)&rstr);
 	int		len = (int)RSTRING_LEN(rstr);
-	    
+
 	if (0 == strcasecmp("Infinity", str)) {
 	    str = oj_nan_str(obj, out->opts->dump_opts.nan_dump, out->opts->mode, true, &len);
 	    oj_dump_raw(str, len, out);
@@ -204,7 +204,7 @@ dump_str_class(VALUE obj, VALUE clas, int depth, Out out) {
 	dump_obj_attrs(obj, clas, 0, depth, out);
     } else {
 	const char	*s = rb_string_value_ptr((VALUE*)&obj);
-	size_t		len = RSTRING_LEN(obj);
+	size_t		len = (int)RSTRING_LEN(obj);
 	char		s1 = s[1];
 
 	oj_dump_cstr(s, len, 0, (':' == *s || ('^' == *s && ('r' == s1 || 'i' == s1))), out);
@@ -218,13 +218,14 @@ dump_str(VALUE obj, int depth, Out out, bool as_ok) {
 
 static void
 dump_sym(VALUE obj, int depth, Out out, bool as_ok) {
-    const char	*sym = rb_id2name(SYM2ID(obj));
-    
-    oj_dump_cstr(sym, strlen(sym), 1, 0, out);
+    volatile VALUE	s = rb_sym_to_s(obj);
+
+    oj_dump_cstr(rb_string_value_ptr((VALUE*)&s), (int)RSTRING_LEN(s), 1, 0, out);
 }
 
 static int
-hash_cb(VALUE key, VALUE value, Out out) {
+hash_cb(VALUE key, VALUE value, VALUE ov) {
+    Out		out = (Out)ov;
     int		depth = out->depth;
     long	size = depth * out->indent + 1;
 
@@ -280,7 +281,7 @@ hash_cb(VALUE key, VALUE value, Out out) {
     }
     out->depth = depth;
     *out->cur++ = ',';
-    
+
     return ST_CONTINUE;
 }
 
@@ -346,9 +347,10 @@ dump_hash_class(VALUE obj, VALUE clas, int depth, Out out) {
     *out->cur = '\0';
 }
 
-#if HAS_IVAR_HELPERS
+#ifdef HAVE_RB_IVAR_FOREACH
 static int
-dump_attr_cb(ID key, VALUE value, Out out) {
+dump_attr_cb(ID key, VALUE value, VALUE ov) {
+    Out		out = (Out)ov;
     int		depth = out->depth;
     size_t	size = depth * out->indent + 1;
     const char	*attr = rb_id2name(key);
@@ -363,12 +365,12 @@ dump_attr_cb(ID key, VALUE value, Out out) {
     // the key name is NULL. Not an empty string but NULL.
     if (NULL == attr) {
 	attr = "";
+    } else if (Yes == out->opts->ignore_under && '@' == *attr && '_' == attr[1]) {
+	return ST_CONTINUE;
     }
-#if HAS_EXCEPTION_MAGIC
     if (0 == strcmp("bt", attr) || 0 == strcmp("mesg", attr)) {
 	return ST_CONTINUE;
     }
-#endif
     assure_size(out, size);
     fill_indent(out, depth);
     if ('@' == *attr) {
@@ -386,7 +388,7 @@ dump_attr_cb(ID key, VALUE value, Out out) {
     oj_dump_obj_val(value, depth, out);
     out->depth = depth;
     *out->cur++ = ',';
-    
+
     return ST_CONTINUE;
 }
 #endif
@@ -425,8 +427,8 @@ dump_odd(VALUE obj, Odd odd, VALUE clas, int depth, Out out) {
     if (odd->raw) {
 	v = rb_funcall(obj, *odd->attrs, 0);
 	if (Qundef == v || T_STRING != rb_type(v)) {
-	    rb_raise(rb_eEncodingError, "Invalid type for raw JSON.\n");
-	} else {	    
+	    rb_raise(rb_eEncodingError, "Invalid type for raw JSON.");
+	} else {
 	    const char	*s = rb_string_value_ptr((VALUE*)&v);
 	    int		len = (int)RSTRING_LEN(v);
 	    const char	*name = rb_id2name(*odd->attrs);
@@ -462,9 +464,11 @@ dump_odd(VALUE obj, Odd odd, VALUE clas, int depth, Out out) {
 		char	*n;
 		char	*end;
 		ID	i;
-	    
+
 		if (sizeof(nbuf) <= nlen) {
-		    n2 = strdup(name);
+		    if (NULL == (n2 = strdup(name))) {
+			rb_raise(rb_eNoMemError, "for attribute name.");
+		    }
 		} else {
 		    strcpy(n2, name);
 		}
@@ -544,7 +548,7 @@ dump_obj_attrs(VALUE obj, VALUE clas, slot_t id, int depth, Out out) {
 	*out->cur++ = 'f';
 	*out->cur++ = '"';
 	*out->cur++ = ':';
-	oj_dump_cstr(rb_string_value_ptr((VALUE*)&obj), RSTRING_LEN(obj), 0, 0, out);
+	oj_dump_cstr(rb_string_value_ptr((VALUE*)&obj), (int)RSTRING_LEN(obj), 0, 0, out);
 	break;
     case T_ARRAY:
 	assure_size(out, d2 * out->indent + 14);
@@ -577,7 +581,7 @@ dump_obj_attrs(VALUE obj, VALUE clas, slot_t id, int depth, Out out) {
     }
     {
 	int	cnt;
-#if HAS_IVAR_HELPERS
+#ifdef HAVE_RB_IVAR_COUNT
 	cnt = (int)rb_ivar_count(obj);
 #else
 	volatile VALUE	vars = rb_funcall2(obj, oj_instance_variables_id, 0, 0);
@@ -601,7 +605,7 @@ dump_obj_attrs(VALUE obj, VALUE clas, slot_t id, int depth, Out out) {
 	    }
 	}
 	out->depth = depth + 1;
-#if HAS_IVAR_HELPERS
+#ifdef HAVE_RB_IVAR_FOREACH
 	rb_ivar_foreach(obj, dump_attr_cb, (VALUE)out);
 	if (',' == *(out->cur - 1)) {
 	    out->cur--; // backup to overwrite last comma
@@ -610,9 +614,12 @@ dump_obj_attrs(VALUE obj, VALUE clas, slot_t id, int depth, Out out) {
 	size = d2 * out->indent + 1;
 	for (i = cnt; 0 < i; i--, np++) {
 	    VALUE	value;
-	    
+
 	    vid = rb_to_id(*np);
 	    attr = rb_id2name(vid);
+	    if (Yes == out->opts->ignore_under && '@' == *attr && '_' == attr[1]) {
+		return ST_CONTINUE;
+	    }
 	    value = rb_ivar_get(obj, vid);
 
 	    if (oj_dump_ignore(out->opts, value)) {
@@ -644,7 +651,6 @@ dump_obj_attrs(VALUE obj, VALUE clas, slot_t id, int depth, Out out) {
 	    assure_size(out, 2);
 	}
 #endif
-#if HAS_EXCEPTION_MAGIC
 	if (rb_obj_is_kind_of(obj, rb_eException)) {
 	    volatile VALUE	rv;
 
@@ -669,7 +675,6 @@ dump_obj_attrs(VALUE obj, VALUE clas, slot_t id, int depth, Out out) {
 	    oj_dump_obj_val(rv, d2, out);
 	    assure_size(out, 2);
 	}
-#endif
 	out->depth = depth;
     }
     fill_indent(out, depth);
@@ -701,7 +706,6 @@ dump_struct(VALUE obj, int depth, Out out, bool as_ok) {
     *out->cur++ = '"';
     *out->cur++ = ':';
     *out->cur++ = '[';
-#if HAS_STRUCT_MEMBERS
     if ('#' == *class_name) {
 	VALUE		ma = rb_struct_s_members(clas);
 	const char	*name;
@@ -709,8 +713,10 @@ dump_struct(VALUE obj, int depth, Out out, bool as_ok) {
 
 	*out->cur++ = '[';
 	for (i = 0; i < cnt; i++) {
-	    name = rb_id2name(SYM2ID(rb_ary_entry(ma, i)));
-	    len = strlen(name);
+	    volatile VALUE	s = rb_sym_to_s(rb_ary_entry(ma, i));
+
+	    name = rb_string_value_ptr((VALUE*)&s);
+	    len = (int)RSTRING_LEN(s);
 	    size = len + 3;
 	    assure_size(out, size);
 	    if (0 < i) {
@@ -723,9 +729,6 @@ dump_struct(VALUE obj, int depth, Out out, bool as_ok) {
 	}
 	*out->cur++ = ']';
     } else {
-#else
-    if (true) {
-#endif
 	fill_indent(out, d3);
 	*out->cur++ = '"';
 	memcpy(out->cur, class_name, len);
@@ -743,7 +746,7 @@ dump_struct(VALUE obj, int depth, Out out, bool as_ok) {
 #else // RSTRUCT_LEN_RETURNS_INTEGER_OBJECT
 	cnt = (int)RSTRUCT_LEN(obj);
 #endif // RSTRUCT_LEN_RETURNS_INTEGER_OBJECT
-	
+
 	for (i = 0; i < cnt; i++) {
 	    v = RSTRUCT_GET(obj, i);
 	    if (oj_dump_ignore(out->opts, v)) {
@@ -816,7 +819,7 @@ static DumpFunc	obj_funcs[] = {
 void
 oj_dump_obj_val(VALUE obj, int depth, Out out) {
     int	type = rb_type(obj);
-    
+
     if (Yes == out->opts->trace) {
 	oj_trace("dump", obj, __FILE__, __LINE__, depth, TraceIn);
     }
