@@ -28,6 +28,7 @@ have_func('rb_ivar_count')
 have_func('rb_ivar_foreach')
 have_func('stpcpy')
 have_func('rb_data_object_wrap')
+have_func('pthread_mutex_init')
 
 dflags['OJ_DEBUG'] = true unless ENV['OJ_DEBUG'].nil?
 
@@ -41,6 +42,11 @@ end
 
 $CPPFLAGS += ' -Wall'
 #puts "*** $CPPFLAGS: #{$CPPFLAGS}"
+# Adding the __attribute__ flag only works with gcc compilers and even then it
+# does not work to check args with varargs so just remove the check.
+CONFIG['warnflags'].slice!(/ -Wsuggest-attribute=format/)
+CONFIG['warnflags'].slice!(/ -Wdeclaration-after-statement/)
+CONFIG['warnflags'].slice!(/ -Wmissing-noreturn/)
 
 create_makefile(File.join(extension_name, extension_name))
 
