@@ -3,6 +3,7 @@
  * All rights reserved.
  */
 
+#include <stdint.h>
 #include <stdio.h>
 #include <time.h>
 
@@ -14,6 +15,7 @@
 #include "odd.h"
 #include "encode.h"
 #include "trace.h"
+#include "util.h"
 
 inline static long
 read_long(const char *str, size_t len) {
@@ -274,7 +276,10 @@ hat_num(ParseInfo pi, Val parent, Val kval, NumInfo ni) {
     if (2 == kval->klen) {
 	switch (kval->key[1]) {
 	case 't': // time as a float
-	    {
+	    if (0 == ni->div || 9 < ni->di) {
+		rb_raise(rb_eArgError, "Invalid time decimal representation.");
+		//parent->val = rb_time_nano_new(0, 0);
+	    } else {
 		int64_t	nsec = ni->num * 1000000000LL / ni->div;
 
 		if (ni->neg) {
@@ -291,24 +296,19 @@ hat_num(ParseInfo pi, Val parent, Val kval, NumInfo ni) {
 		    // match the expected value.
 		    parent->val = rb_funcall2(parent->val, oj_utc_id, 0, 0);
 		} else if (ni->hasExp) {
-		    time_t	t = (time_t)(ni->i + ni->exp);
-		    struct tm	*st = gmtime(&t);
-		    VALUE	args[8];
+		    int64_t		t = (int64_t)(ni->i + ni->exp);
+		    struct _timeInfo	ti;
+		    VALUE		args[8];
 
-		    // Windows does not support dates before 1970 so ignore
-		    // the zone and do the best we can.
-		    if (NULL == st) {
-			parent->val = rb_time_nano_new(ni->i, (long)nsec);
-		    } else {
-			args[0] = LONG2NUM((long)(1900 + st->tm_year));
-			args[1] = LONG2NUM(1 + st->tm_mon);
-			args[2] = LONG2NUM(st->tm_mday);
-			args[3] = LONG2NUM(st->tm_hour);
-			args[4] = LONG2NUM(st->tm_min);
-			args[5] = rb_float_new((double)st->tm_sec + ((double)nsec + 0.5) / 1000000000.0);
-			args[6] = LONG2NUM(ni->exp);
-			parent->val = rb_funcall2(rb_cTime, oj_new_id, 7, args);
-		    }
+		    sec_as_time(t, &ti);
+		    args[0] = LONG2NUM((long)(ti.year));
+		    args[1] = LONG2NUM(ti.mon);
+		    args[2] = LONG2NUM(ti.day);
+		    args[3] = LONG2NUM(ti.hour);
+		    args[4] = LONG2NUM(ti.min);
+		    args[5] = rb_float_new((double)ti.sec + ((double)nsec + 0.5) / 1000000000.0);
+		    args[6] = LONG2NUM(ni->exp);
+		    parent->val = rb_funcall2(rb_cTime, oj_new_id, 7, args);
 		} else {
 		    parent->val = rb_time_nano_new(ni->i, (long)nsec);
 		}
@@ -403,23 +403,6 @@ hat_value(ParseInfo pi, Val parent, const char *key, size_t klen, volatile VALUE
     return 0;
 }
 
-static void
-copy_ivars(VALUE target, VALUE src) {
-    volatile VALUE	vars = rb_funcall(src, oj_instance_variables_id, 0);
-    volatile VALUE	*np = RARRAY_PTR(vars);
-    ID			vid;
-    int			i, cnt = (int)RARRAY_LEN(vars);
-    const char		*attr;
-
-    for (i = cnt; 0 < i; i--, np++) {
-	vid = rb_to_id(*np);
-	attr = rb_id2name(vid);
-	if ('@' == *attr) {
-	    rb_ivar_set(target, vid, rb_ivar_get(src, vid));
-	}
-    }
-}
-
 void
 oj_set_obj_ivar(Val parent, Val kval, VALUE value) {
     const char	*key = kval->key;
@@ -427,19 +410,7 @@ oj_set_obj_ivar(Val parent, Val kval, VALUE value) {
     ID		var_id;
     ID		*slot;
 
-    if ('~' == *key && Qtrue == rb_obj_is_kind_of(parent->val, rb_eException)) {
-	if (5 == klen && 0 == strncmp("~mesg", key, klen)) {
-	    VALUE		args[1];
-	    volatile VALUE	prev = parent->val;
-
-	    args[0] = value;
-	    parent->val = rb_class_new_instance(1, args, rb_class_of(parent->val));
-	    copy_ivars(parent->val, prev);
-	} else if (3 == klen && 0 == strncmp("~bt", key, klen)) {
-	    rb_funcall(parent->val, rb_intern("set_backtrace"), 1, value);
-	}
-    }
-#if HAVE_LIBPTHREAD
+#ifdef HAVE_PTHREAD_MUTEX_INIT
     pthread_mutex_lock(&oj_cache_mutex);
 #else
     rb_mutex_lock(oj_cache_mutex);
@@ -473,7 +444,7 @@ oj_set_obj_ivar(Val parent, Val kval, VALUE value) {
 	}
 	*slot = var_id;
     }
-#if HAVE_LIBPTHREAD
+#ifdef HAVE_PTHREAD_MUTEX_INIT
     pthread_mutex_unlock(&oj_cache_mutex);
 #else
     rb_mutex_unlock(oj_cache_mutex);
@@ -491,7 +462,7 @@ hash_set_cstr(ParseInfo pi, Val kval, const char *str, size_t len, const char *o
  WHICH_TYPE:
     switch (rb_type(parent->val)) {
     case T_NIL:
-	parent->odd_args = 0; // make sure it is 0 in case not odd
+	parent->odd_args = NULL; // make sure it is NULL in case not odd
 	if ('^' != *key || !hat_cstr(pi, parent, kval, str, len)) {
 	    parent->val = rb_hash_new();
 	    goto WHICH_TYPE;
@@ -513,7 +484,7 @@ hash_set_cstr(ParseInfo pi, Val kval, const char *str, size_t len, const char *o
 	oj_set_obj_ivar(parent, kval, rval);
 	break;
     case T_CLASS:
-	if (0 == parent->odd_args) {
+	if (NULL == parent->odd_args) {
 	    oj_set_error_at(pi, oj_parse_error_class, __FILE__, __LINE__, "%s is not an odd class", rb_class2name(rb_obj_class(parent->val)));
 	    return;
 	} else {
@@ -549,7 +520,7 @@ hash_set_num(ParseInfo pi, Val kval, NumInfo ni) {
  WHICH_TYPE:
     switch (rb_type(parent->val)) {
     case T_NIL:
-	parent->odd_args = 0; // make sure it is 0 in case not odd
+	parent->odd_args = NULL; // make sure it is NULL in case not odd
 	if ('^' != *key || !hat_num(pi, parent, kval, ni)) {
 	    parent->val = rb_hash_new();
 	    goto WHICH_TYPE;
@@ -569,7 +540,7 @@ hash_set_num(ParseInfo pi, Val kval, NumInfo ni) {
 	}
 	break;
     case T_CLASS:
-	if (0 == parent->odd_args) {
+	if (NULL == parent->odd_args) {
 	    oj_set_error_at(pi, oj_parse_error_class, __FILE__, __LINE__, "%s is not an odd class", rb_class2name(rb_obj_class(parent->val)));
 	    return;
 	} else {
@@ -604,7 +575,7 @@ hash_set_value(ParseInfo pi, Val kval, VALUE value) {
  WHICH_TYPE:
     switch (rb_type(parent->val)) {
     case T_NIL:
-	parent->odd_args = 0; // make sure it is 0 in case not odd
+	parent->odd_args = NULL; // make sure it is NULL in case not odd
 	if ('^' != *key || !hat_value(pi, parent, key, klen, value)) {
 	    parent->val = rb_hash_new();
 	    goto WHICH_TYPE;
@@ -645,7 +616,7 @@ hash_set_value(ParseInfo pi, Val kval, VALUE value) {
 	break;
     case T_MODULE:
     case T_CLASS:
-	if (0 == parent->odd_args) {
+	if (NULL == parent->odd_args) {
 	    oj_set_error_at(pi, oj_parse_error_class, __FILE__, __LINE__, "%s is not an odd class", rb_class2name(rb_obj_class(parent->val)));
 	    return;
 	} else if (0 !=	oj_odd_set_arg(parent->odd_args, key, klen, value)) {
@@ -682,12 +653,12 @@ end_hash(ParseInfo pi) {
 
     if (Qnil == parent->val) {
 	parent->val = rb_hash_new();
-    } else if (0 != parent->odd_args) {
+    } else if (NULL != parent->odd_args) {
 	OddArgs	oa = parent->odd_args;
 
 	parent->val = rb_funcall2(oa->odd->create_obj, oa->odd->create_op, oa->odd->attr_cnt, oa->args);
 	oj_odd_free(oa);
-	parent->odd_args = 0;
+	parent->odd_args = NULL;
     }
     if (Yes == pi->options.trace) {
 	oj_trace_parse_hash_end(pi, __FILE__, __LINE__);
@@ -697,7 +668,7 @@ end_hash(ParseInfo pi) {
 static void
 array_append_cstr(ParseInfo pi, const char *str, size_t len, const char *orig) {
     volatile VALUE	rval = Qnil;
-    
+
     if (3 <= len && 0 != pi->circ_array) {
 	if ('i' == str[1]) {
 	    long	i = read_long(str + 2, len - 2);
@@ -726,7 +697,7 @@ array_append_cstr(ParseInfo pi, const char *str, size_t len, const char *orig) {
 static void
 array_append_num(ParseInfo pi, NumInfo ni) {
     volatile VALUE	rval = oj_num_as_value(ni);
-    
+
     rb_ary_push(stack_peek(&pi->stack)->val, rval);
     if (Yes == pi->options.trace) {
 	oj_trace_parse_call("append_number", pi, __FILE__, __LINE__, rval);
