@@ -119,6 +119,7 @@ static VALUE	float_prec_sym;
 static VALUE	float_sym;
 static VALUE	huge_sym;
 static VALUE	ignore_sym;
+static VALUE	ignore_under_sym;
 static VALUE	json_sym;
 static VALUE	match_string_sym;
 static VALUE	mode_sym;
@@ -149,7 +150,7 @@ static VALUE	xss_safe_sym;
 
 rb_encoding	*oj_utf8_encoding = 0;
 
-#if HAVE_LIBPTHREAD
+#ifdef HAVE_PTHREAD_MUTEX_INIT
 pthread_mutex_t	oj_cache_mutex;
 #else
 VALUE oj_cache_mutex = Qnil;
@@ -181,8 +182,10 @@ struct _options	oj_default_options = {
     Yes,	// allow_nan
     No,		// trace
     No,		// safe
-    0,		// integer_range_min
-    0,		// integer_range_max
+    false,	// sec_prec_set
+    No,		// ignore_under
+    0,		// int_range_min
+    0,		// int_range_max
     oj_json_class,	// create_id
     10,		// create_id_len
     9,		// sec_prec
@@ -251,6 +254,7 @@ struct _options	oj_default_options = {
  * - *:array_class* [_Class_|_nil_] Class to use instead of Array on load
  * - *:omit_nil* [_true_|_false_] if true Hash and Object attributes with nil values are omitted
  * - *:ignore* [_nil_|Array] either nil or an Array of classes to ignore when dumping
+ * - *:ignore_under* [Boolean] if true then attributes that start with _ are ignored when dumping in object or custom mode.
  * - *:integer_range* [_Range_] Dump integers outside range as strings.
  * - *:trace* [_true,_|_false_] Trace all load and dump calls, default is false (trace is off)
  * - *:safe* [_true,_|_false_] Safe mimic breaks JSON mimic to be safer, default is false (safe is off)
@@ -286,6 +290,7 @@ get_def_opts(VALUE self) {
     rb_hash_aset(opts, oj_trace_sym, (Yes == oj_default_options.trace) ? Qtrue : ((No == oj_default_options.trace) ? Qfalse : Qnil));
     rb_hash_aset(opts, oj_safe_sym, (Yes == oj_default_options.safe) ? Qtrue : ((No == oj_default_options.safe) ? Qfalse : Qnil));
     rb_hash_aset(opts, float_prec_sym, INT2FIX(oj_default_options.float_prec));
+    rb_hash_aset(opts, ignore_under_sym, (Yes == oj_default_options.ignore_under) ? Qtrue : ((No == oj_default_options.ignore_under) ? Qfalse : Qnil));
     switch (oj_default_options.mode) {
     case StrictMode:	rb_hash_aset(opts, mode_sym, strict_sym);	break;
     case CompatMode:	rb_hash_aset(opts, mode_sym, compat_sym);	break;
@@ -297,16 +302,16 @@ get_def_opts(VALUE self) {
     default:		rb_hash_aset(opts, mode_sym, object_sym);	break;
     }
 
-    if (oj_default_options.integer_range_max != 0 || oj_default_options.integer_range_min != 0) {
-    VALUE range = rb_obj_alloc(rb_cRange);
-    VALUE min = LONG2FIX(oj_default_options.integer_range_min);
-    VALUE max = LONG2FIX(oj_default_options.integer_range_max);
-    rb_ivar_set(range, oj_begin_id, min);
-    rb_ivar_set(range, oj_end_id, max);
-    rb_hash_aset(opts, integer_range_sym, range);
-    }
-    else {
-    rb_hash_aset(opts, integer_range_sym, Qnil);
+    if (oj_default_options.int_range_max != 0 || oj_default_options.int_range_min != 0) {
+	VALUE	range = rb_obj_alloc(rb_cRange);
+	VALUE	min = LONG2FIX(oj_default_options.int_range_min);
+	VALUE	max = LONG2FIX(oj_default_options.int_range_max);
+
+	rb_ivar_set(range, oj_begin_id, min);
+	rb_ivar_set(range, oj_end_id, max);
+	rb_hash_aset(opts, integer_range_sym, range);
+    } else {
+	rb_hash_aset(opts, integer_range_sym, Qnil);
     }
     switch (oj_default_options.escape_mode) {
     case NLEsc:		rb_hash_aset(opts, escape_mode_sym, newline_sym);	break;
@@ -329,7 +334,7 @@ get_def_opts(VALUE self) {
     case AutoDec:
     default:		rb_hash_aset(opts, bigdecimal_load_sym, auto_sym);	break;
     }
-    rb_hash_aset(opts, create_id_sym, (0 == oj_default_options.create_id) ? Qnil : rb_str_new2(oj_default_options.create_id));
+    rb_hash_aset(opts, create_id_sym, (NULL == oj_default_options.create_id) ? Qnil : rb_str_new2(oj_default_options.create_id));
     rb_hash_aset(opts, oj_space_sym, (0 == oj_default_options.dump_opts.after_size) ? Qnil : rb_str_new2(oj_default_options.dump_opts.after_sep));
     rb_hash_aset(opts, oj_space_before_sym, (0 == oj_default_options.dump_opts.before_size) ? Qnil : rb_str_new2(oj_default_options.dump_opts.before_sep));
     rb_hash_aset(opts, oj_object_nl_sym, (0 == oj_default_options.dump_opts.hash_size) ? Qnil : rb_str_new2(oj_default_options.dump_opts.hash_nl));
@@ -398,6 +403,7 @@ get_def_opts(VALUE self) {
  *   - *:array_class* [_Class_|_nil_] Class to use instead of Array on load.
  *   - *:omit_nil* [_true_|_false_] if true Hash and Object attributes with nil values are omitted.
  *   - *:ignore* [_nil_|Array] either nil or an Array of classes to ignore when dumping
+ *   - *:ignore_under* [_Boolean_] if true then attributes that start with _ are ignored when dumping in object or custom mode.
  *   - *:integer_range* [_Range_] Dump integers outside range as strings.
  *   - *:trace* [_Boolean_] turn trace on or off.
  *   - *:safe* [_Boolean_] turn safe mimic on or off.
@@ -431,6 +437,7 @@ oj_parse_options(VALUE ropts, Options copts) {
 	{ oj_allow_nan_sym, &copts->allow_nan },
 	{ oj_trace_sym, &copts->trace },
 	{ oj_safe_sym, &copts->safe },
+	{ ignore_under_sym, &copts->ignore_under },
 	{ oj_create_additions_sym, &copts->create_ok },
 	{ Qnil, 0 }
     };
@@ -506,8 +513,12 @@ oj_parse_options(VALUE ropts, Options copts) {
 	n = NUM2INT(v);
 	if (0 > n) {
 	    n = 0;
+	    copts->sec_prec_set = false;
 	} else if (9 < n) {
 	    n = 9;
+	    copts->sec_prec_set = true;
+	} else {
+	    copts->sec_prec_set = true;
 	}
 	copts->sec_prec = n;
     }
@@ -738,24 +749,26 @@ oj_parse_options(VALUE ropts, Options copts) {
 	}
     }
     if (Qnil != (v = rb_hash_lookup(ropts, integer_range_sym))) {
-    if (TYPE(v) == T_STRUCT && rb_obj_class(v) == rb_cRange) {
-        VALUE min = rb_funcall(v, oj_begin_id, 0);
-        VALUE max = rb_funcall(v, oj_end_id, 0);
+	if (TYPE(v) == T_STRUCT && rb_obj_class(v) == rb_cRange) {
+	    VALUE min = rb_funcall(v, oj_begin_id, 0);
+	    VALUE max = rb_funcall(v, oj_end_id, 0);
 
-        if (TYPE(min) != T_FIXNUM || TYPE(max) != T_FIXNUM) {
-            rb_raise(rb_eArgError, ":integer_range range bounds is not Fixnum.");
-        }
+	    if (TYPE(min) != T_FIXNUM || TYPE(max) != T_FIXNUM) {
+		rb_raise(rb_eArgError, ":integer_range range bounds is not Fixnum.");
+	    }
 
-        copts->integer_range_min = FIX2LONG(min);
-        copts->integer_range_max = FIX2LONG(max);
-    } else if (Qfalse != v) {
-        rb_raise(rb_eArgError, ":integer_range must be a range of Fixnum.");
-    }
+	    copts->int_range_min = FIX2LONG(min);
+	    copts->int_range_max = FIX2LONG(max);
+	} else if (Qfalse != v) {
+	    rb_raise(rb_eArgError, ":integer_range must be a range of Fixnum.");
+	}
     }
 }
 
 static int
-match_string_cb(VALUE key, VALUE value, RxClass rc) {
+match_string_cb(VALUE key, VALUE value, VALUE rx) {
+    RxClass	rc = (RxClass)rx;
+
     if (T_CLASS != rb_type(value)) {
 	rb_raise(rb_eArgError, "for :match_string, the hash values must be a Class.");
     }
@@ -954,11 +967,13 @@ load_file(int argc, VALUE *argv, VALUE self) {
     }
     switch (mode) {
     case StrictMode:
+    case NullMode:
 	oj_set_strict_callbacks(&pi);
 	return oj_pi_sparse(argc, argv, &pi, fd);
-    case NullMode:
-    case CompatMode:
     case CustomMode:
+	oj_set_custom_callbacks(&pi);
+	return oj_pi_sparse(argc, argv, &pi, fd);
+    case CompatMode:
     case RailsMode:
 	oj_set_compat_callbacks(&pi);
 	return oj_pi_sparse(argc, argv, &pi, fd);
@@ -1052,6 +1067,9 @@ dump(int argc, VALUE *argv, VALUE self) {
     if (2 == argc) {
 	oj_parse_options(argv[1], &copts);
     }
+    if (CompatMode == copts.mode && copts.escape_mode != ASCIIEsc) {
+	copts.escape_mode = JSONEsc;
+    }
     out.buf = buf;
     out.end = buf + sizeof(buf) - 10;
     out.allocated = false;
@@ -1640,6 +1658,7 @@ Init_oj() {
     float_sym = ID2SYM(rb_intern("float"));			rb_gc_register_address(&float_sym);
     huge_sym = ID2SYM(rb_intern("huge"));			rb_gc_register_address(&huge_sym);
     ignore_sym = ID2SYM(rb_intern("ignore"));			rb_gc_register_address(&ignore_sym);
+    ignore_under_sym = ID2SYM(rb_intern("ignore_under"));	rb_gc_register_address(&ignore_under_sym);
     json_sym = ID2SYM(rb_intern("json"));			rb_gc_register_address(&json_sym);
     match_string_sym = ID2SYM(rb_intern("match_string"));	rb_gc_register_address(&match_string_sym);
     mode_sym = ID2SYM(rb_intern("mode"));			rb_gc_register_address(&mode_sym);
@@ -1692,7 +1711,7 @@ Init_oj() {
     oj_odd_init();
     oj_mimic_rails_init();
 
-#if HAVE_LIBPTHREAD
+#ifdef HAVE_PTHREAD_MUTEX_INIT
     if (0 != (err = pthread_mutex_init(&oj_cache_mutex, 0))) {
 	rb_raise(rb_eException, "failed to initialize a mutex. %s", strerror(err));
     }
