@@ -21,7 +21,7 @@ extern "C" {
 #include <stdint.h>
 #include <stdbool.h>
 
-#if HAVE_LIBPTHREAD
+#ifdef HAVE_PTHREAD_MUTEX_INIT
 #include <pthread.h>
 #endif
 #include "cache8.h"
@@ -149,8 +149,10 @@ typedef struct _options {
     char		allow_nan;	// YEsyNo for parsing only
     char		trace;		// YesNo
     char		safe;		// YesNo
-    int64_t		integer_range_min; // dump numbers outside range as string
-    int64_t		integer_range_max;
+    char		sec_prec_set;	// boolean (0 or 1)
+    char		ignore_under;	// YesNo - ignore attrs starting with _ if true in object and custom modes
+    int64_t		int_range_min;	// dump numbers below as string
+    int64_t		int_range_max;	// dump numbers above as string
     const char		*create_id;	// 0 or string
     size_t		create_id_len;	// length of create_id
     int			sec_prec;	// second precision when dumping time
@@ -370,7 +372,7 @@ extern bool	oj_use_hash_alt;
 extern bool	oj_use_array_alt;
 extern bool	string_writer_optimized;
 
-#if HAVE_LIBPTHREAD
+#ifdef HAVE_PTHREAD_MUTEX_INIT
 extern pthread_mutex_t	oj_cache_mutex;
 #else
 extern VALUE	oj_cache_mutex;
