@@ -400,6 +400,10 @@ read_num(ParseInfo pi) {
 	pi->cur++;
 	ni.neg = 1;
     } else if ('+' == *pi->cur) {
+	if (StrictMode == pi->options.mode) {
+	    oj_set_error_at(pi, oj_parse_error_class, __FILE__, __LINE__, "not a number or other value");
+	    return;
+	}
 	pi->cur++;
     }
     if ('I' == *pi->cur) {
@@ -446,8 +450,13 @@ read_num(ParseInfo pi) {
 	if ('.' == *pi->cur) {
 	    pi->cur++;
 	    // A trailing . is not a valid decimal but if encountered allow it
-	    // except when mimicing the JSON gem.
-	    if (CompatMode == pi->options.mode) {
+	    // except when mimicing the JSON gem or in strict mode.
+	    if (StrictMode == pi->options.mode || CompatMode == pi->options.mode) {
+		int	pos = (int)(pi->cur - ni.str);
+		if (1 == pos || (2 == pos && ni.neg)) {
+		    oj_set_error_at(pi, oj_parse_error_class, __FILE__, __LINE__, "not a number");
+		    return;
+		}
 		if (*pi->cur < '0' || '9' < *pi->cur) {
 		    oj_set_error_at(pi, oj_parse_error_class, __FILE__, __LINE__, "not a number");
 		    return;
@@ -731,7 +740,7 @@ oj_parse2(ParseInfo pi) {
 }
 
 static VALUE
-rescue_big_decimal(VALUE str) {
+rescue_big_decimal(VALUE str, VALUE ignore) {
     rb_raise(oj_parse_error_class, "Invalid value for BigDecimal()");
     return Qnil;
 }
@@ -1049,6 +1058,10 @@ CLEANUP:
 		msg = rb_str_append(msg, oj_encode(rb_str_new2(pi->json)));
 	    }
 	    args[0] = msg;
+	    if (pi->err.clas == oj_parse_error_class) {
+		// The error was an Oj::ParseError so change to a JSON::ParserError.
+		pi->err.clas = oj_json_parser_error_class;
+	    }
 	    rb_exc_raise(rb_class_new_instance(1, args, pi->err.clas));
 	} else {
 	    oj_err_raise(&pi->err);
