@@ -87,7 +87,8 @@ copy_opts(ROptTable src, ROptTable dest) {
 }
 
 static int
-dump_attr_cb(ID key, VALUE value, Out out) {
+dump_attr_cb(ID key, VALUE value, VALUE ov) {
+    Out		out = (Out)ov;
     int		depth = out->depth;
     size_t	size = depth * out->indent + 1;
     const char	*attr = rb_id2name(key);
@@ -214,6 +215,8 @@ dump_bigdecimal(VALUE obj, int depth, Out out, bool as_ok) {
 
     if ('I' == *str || 'N' == *str || ('-' == *str && 'I' == str[1])) {
 	oj_dump_nil(Qnil, depth, out, false);
+    } else if (out->opts->int_range_max != 0 || out->opts->int_range_min != 0) {
+	oj_dump_cstr(str, (int)RSTRING_LEN(rstr), 0, 0, out);
     } else if (Yes == out->opts->bigdec_as_num) {
 	oj_dump_raw(str, (int)RSTRING_LEN(rstr), out);
     } else {
@@ -1009,9 +1012,11 @@ rails_encode(int argc, VALUE *argv, VALUE self) {
     }
 }
 
+// TBD provide a get function as well
 static VALUE
 rails_use_standard_json_time_format(VALUE self, VALUE state) {
     if (Qtrue == state || Qfalse == state) {
+	// no change needed
     } else if (Qnil == state) {
 	state = Qfalse;
     } else {
@@ -1023,6 +1028,11 @@ rails_use_standard_json_time_format(VALUE self, VALUE state) {
     return state;
 }
 
+static VALUE
+rails_use_standard_json_time_format_get(VALUE self) {
+    return xml_time ? Qtrue : Qfalse;
+}
+
 static VALUE
 rails_escape_html_entities_in_json(VALUE self, VALUE state) {
     rb_iv_set(self, "@escape_html_entities_in_json", state);
@@ -1031,10 +1041,16 @@ rails_escape_html_entities_in_json(VALUE self, VALUE state) {
     return state;
 }
 
+static VALUE
+rails_escape_html_entities_in_json_get(VALUE self) {
+    return escape_html ? Qtrue : Qfalse;
+}
+
 static VALUE
 rails_time_precision(VALUE self, VALUE prec) {
     rb_iv_set(self, "@time_precision", prec);
     oj_default_options.sec_prec = NUM2INT(prec);
+    oj_default_options.sec_prec_set = true;
 
     return prec;
 }
@@ -1053,7 +1069,12 @@ rails_set_encoder(VALUE self) {
     VALUE	encoding;
     VALUE	pv;
     VALUE	verbose;
+    VALUE	enc = resolve_classpath("ActiveSupport::JSON::Encoding");
 
+    if (Qnil != enc) {
+	escape_html = Qtrue == rb_iv_get(self, "@escape_html_entities_in_json");
+	xml_time = Qtrue == rb_iv_get(enc, "@use_standard_json_time_format");
+    }
     if (rb_const_defined_at(rb_cObject, rb_intern("ActiveSupport"))) {
 	active = rb_const_get_at(rb_cObject, rb_intern("ActiveSupport"));
     } else {
@@ -1070,12 +1091,19 @@ rails_set_encoder(VALUE self) {
     rb_gv_set("$VERBOSE", Qfalse);
     rb_undef_method(encoding, "use_standard_json_time_format=");
     rb_define_module_function(encoding, "use_standard_json_time_format=", rails_use_standard_json_time_format, 1);
+    rb_undef_method(encoding, "use_standard_json_time_format");
+    rb_define_module_function(encoding, "use_standard_json_time_format", rails_use_standard_json_time_format_get, 0);
 
+    pv = rb_iv_get(encoding, "@escape_html_entities_in_json");
+    escape_html = Qtrue == pv;
     rb_undef_method(encoding, "escape_html_entities_in_json=");
     rb_define_module_function(encoding, "escape_html_entities_in_json=", rails_escape_html_entities_in_json, 1);
+    rb_undef_method(encoding, "escape_html_entities_in_json");
+    rb_define_module_function(encoding, "escape_html_entities_in_json", rails_escape_html_entities_in_json_get, 0);
 
     pv = rb_iv_get(encoding, "@time_precision");
     oj_default_options.sec_prec = NUM2INT(pv);
+    oj_default_options.sec_prec_set = true;
     rb_undef_method(encoding, "time_precision=");
     rb_define_module_function(encoding, "time_precision=", rails_time_precision, 1);
     rb_gv_set("$VERBOSE", verbose);
@@ -1283,7 +1311,8 @@ dump_array(VALUE a, int depth, Out out, bool as_ok) {
 }
 
 static int
-hash_cb(VALUE key, VALUE value, Out out) {
+hash_cb(VALUE key, VALUE value, VALUE ov) {
+    Out		out = (Out)ov;
     int		depth = out->depth;
     long	size;
     int		rtype = rb_type(key);
@@ -1396,14 +1425,17 @@ dump_hash(VALUE obj, int depth, Out out, bool as_ok) {
 
 static void
 dump_obj(VALUE obj, int depth, Out out, bool as_ok) {
+    VALUE	clas;
+
     if (oj_code_dump(oj_compat_codes, obj, depth, out)) {
 	out->argc = 0;
 	return;
     }
+    clas = rb_obj_class(obj);
     if (as_ok) {
 	ROpt	ro;
 
-	if (NULL != (ro = oj_rails_get_opt(out->ropts, rb_obj_class(obj))) && ro->on) {
+	if (NULL != (ro = oj_rails_get_opt(out->ropts, clas)) && ro->on) {
 	    ro->dump(obj, depth, out, as_ok);
 	} else if (Yes == out->opts->raw_json && rb_respond_to(obj, oj_raw_json_id)) {
 	    oj_dump_raw_json(obj, depth, out);
@@ -1411,6 +1443,8 @@ dump_obj(VALUE obj, int depth, Out out, bool as_ok) {
 	    dump_as_json(obj, depth, out, true);
 	} else if (rb_respond_to(obj, oj_to_hash_id)) {
 	    dump_to_hash(obj, depth, out);
+	} else if (oj_bigdecimal_class == clas) {
+	    dump_bigdecimal(obj, depth, out, false);
 	} else {
 	    oj_dump_obj_to_s(obj, out);
 	}
@@ -1419,6 +1453,8 @@ dump_obj(VALUE obj, int depth, Out out, bool as_ok) {
     } else if (rb_respond_to(obj, oj_to_hash_id)) {
 	// Always attempt to_hash.
 	dump_to_hash(obj, depth, out);
+    } else if (oj_bigdecimal_class == clas) {
+	dump_bigdecimal(obj, depth, out, false);
     } else {
 	oj_dump_obj_to_s(obj, out);
     }
@@ -1437,7 +1473,7 @@ static DumpFunc	rails_funcs[] = {
     dump_hash,	 	// RUBY_T_HASH     = 0x08,
     dump_obj,		// RUBY_T_STRUCT   = 0x09,
     oj_dump_bignum,	// RUBY_T_BIGNUM   = 0x0a,
-    NULL, 		// RUBY_T_FILE     = 0x0b,
+    dump_as_string,	// RUBY_T_FILE     = 0x0b,
     dump_obj,		// RUBY_T_DATA     = 0x0c,
     NULL, 		// RUBY_T_MATCH    = 0x0d,
     // Rails raises a stack error on Complex and Rational. It also corrupts
