@@ -3,12 +3,12 @@
  * All rights reserved.
  */
 
-#ifndef __OJ_RESOLVE_H__
-#define __OJ_RESOLVE_H__
+#ifndef OJ_RESOLVE_H
+#define OJ_RESOLVE_H
 
 #include "ruby.h"
 
 extern VALUE	oj_name2class(ParseInfo pi, const char *name, size_t len, int auto_define, VALUE error_class);
 extern VALUE	oj_name2struct(ParseInfo pi, VALUE nameVal, VALUE error_class);
 
-#endif /* __OJ_RESOLVE_H__ */
+#endif /* OJ_RESOLVE_H */
