@@ -773,6 +773,7 @@ oj_sparse2(ParseInfo pi) {
 		first = 0;
 	    }
 	    start = pi->rd.pos;
+	    // TBD break if option set to allow that
 	}
     }
 }
@@ -898,6 +899,10 @@ CLEANUP:
 	    // idea.
 	    VALUE	args[] = { oj_encode(rb_str_new2(pi->err.msg)) };
 
+	    if (pi->err.clas == oj_parse_error_class) {
+		// The error was an Oj::ParseError so change to a JSON::ParserError.
+		pi->err.clas = oj_json_parser_error_class;
+	    }
 	    rb_exc_raise(rb_class_new_instance(1, args, pi->err.clas));
 	} else {
 	    oj_err_raise(&pi->err);
