@@ -1,21 +1,21 @@
 /* val_stack.c
  * Copyright (c) 2011, Peter Ohler
  * All rights reserved.
- * 
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
- * 
+ *
  *  - Redistributions of source code must retain the above copyright notice, this
  *    list of conditions and the following disclaimer.
- * 
+ *
  *  - Redistributions in binary form must reproduce the above copyright notice,
  *    this list of conditions and the following disclaimer in the documentation
  *    and/or other materials provided with the distribution.
- * 
+ *
  *  - Neither the name of Peter Ohler nor the names of its contributors may be
  *    used to endorse or promote products derived from this software without
  *    specific prior written permission.
- * 
+ *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
@@ -31,6 +31,7 @@
 #include <string.h>
 
 #include "oj.h"
+#include "odd.h"
 #include "val_stack.h"
 
 static void
@@ -41,7 +42,7 @@ mark(void *ptr) {
     if (0 == ptr) {
 	return;
     }
-#if HAVE_LIBPTHREAD
+#ifdef HAVE_PTHREAD_MUTEX_INIT
     pthread_mutex_lock(&stack->mutex);
 #else
     rb_mutex_lock(stack->mutex);
@@ -54,8 +55,18 @@ mark(void *ptr) {
 	if (Qnil != v->key_val && Qundef != v->key_val) {
 	    rb_gc_mark(v->key_val);
 	}
+	if (NULL != v->odd_args) {
+	    VALUE	*a;
+	    int		i;
+
+	    for (i = v->odd_args->odd->attr_cnt, a = v->odd_args->args; 0 < i; i--, a++) {
+		if (Qnil != *a) {
+		    rb_gc_mark(*a);
+		}
+	    }
+	}
     }
-#if HAVE_LIBPTHREAD
+#ifdef HAVE_PTHREAD_MUTEX_INIT
     pthread_mutex_unlock(&stack->mutex);
 #else
     rb_mutex_unlock(stack->mutex);
@@ -64,9 +75,9 @@ mark(void *ptr) {
 
 VALUE
 oj_stack_init(ValStack stack) {
-#if HAVE_LIBPTHREAD
+#ifdef HAVE_PTHREAD_MUTEX_INIT
     int	err;
-    
+
     if (0 != (err = pthread_mutex_init(&stack->mutex, 0))) {
 	rb_raise(rb_eException, "failed to initialize a mutex. %s", strerror(err));
     }
@@ -77,12 +88,15 @@ oj_stack_init(ValStack stack) {
     stack->end = stack->base + sizeof(stack->base) / sizeof(struct _val);
     stack->tail = stack->head;
     stack->head->val = Qundef;
-    stack->head->key = 0;
+    stack->head->key = NULL;
     stack->head->key_val = Qundef;
-    stack->head->classname = 0;
+    stack->head->classname = NULL;
+    stack->head->odd_args = NULL;
+    stack->head->clas = Qundef;
     stack->head->klen = 0;
     stack->head->clen = 0;
     stack->head->next = NEXT_NONE;
+
     return Data_Wrap_Struct(oj_cstack_class, mark, 0, stack);
 }
 
