@@ -1,4 +1,4 @@
-#!/usr/bin/env ruby -wW1
+#!/usr/bin/env ruby
 # encoding: UTF-8
 
 $: << '.'
@@ -12,8 +12,6 @@ require 'oj'
 $verbose = false
 $indent = 0
 $iter = 20000
-$with_bignum = false
-$with_nums = true
 $size = 0
 
 opts = OptionParser.new
@@ -24,25 +22,48 @@ opts.on("-s", "--size [Int]", Integer, "size (~Kbytes)")    { |i| $size = i }
 opts.on("-h", "--help", "Show this display")                { puts opts; Process.exit!(0) }
 files = opts.parse(ARGV)
 
+def capture_error(tag, orig, load_key, dump_key, &blk)
+  begin
+    obj = blk.call(orig)
+    puts obj unless orig == obj
+    raise "#{tag} #{dump_key} and #{load_key} did not return the same object as the original." unless orig == obj
+  rescue Exception => e
+    $failed[tag] = "#{e.class}: #{e.message}"
+  end
+end
+
+# Verify that all packages dump and load correctly and return the same Object as the original.
+capture_error('Oj:compat', $obj, 'load', 'dump') { |o| Oj.compat_load(Oj.dump(o, :mode => :compat)) }
+capture_error('JSON::Ext', $obj, 'generate', 'parse') { |o|
+  require 'json'
+  require 'json/ext'
+  JSON.generator = JSON::Ext::Generator
+  JSON.parser = JSON::Ext::Parser
+  JSON.load(JSON.generate(o))
+}
+
 module One
   module Two
     module Three
       class Empty
 
         def initialize()
+          @a = 1
+          @b = 2
+          @c = 3
         end
 
         def eql?(o)
-          self.class == o.class
+          self.class == o.class && @a == o.a && @b = o.b && @c = o.c
         end
         alias == eql?
 
-        def to_hash()
-          {'json_class' => "#{self.class.name}"}
+        def as_json(*a)
+          {JSON.create_id => self.class.name, 'a' => @a, 'b' => @b, 'c' => @c }
         end
-
+        
         def to_json(*a)
-          %{{"json_class":"#{self.class.name}"}}
+          JSON.generate(as_json())
         end
 
         def self.json_create(h)
@@ -65,7 +86,7 @@ $obj = {
   'i' => [[[[[[[nil]]]]]]]  # deep array, again, not that deep
 }
 
-Oj.default_options = { :indent => $indent, :mode => :compat }
+Oj.default_options = { :indent => $indent, :mode => :compat, :use_to_json => true, :create_additions => true, :create_id => '^o' }
 
 if 0 < $size
   s = Oj.dump($obj).size + 1
@@ -80,25 +101,6 @@ end
 $json = Oj.dump($obj)
 $failed = {} # key is same as String used in tests later
 
-def capture_error(tag, orig, load_key, dump_key, &blk)
-  begin
-    obj = blk.call(orig)
-    raise "#{tag} #{dump_key} and #{load_key} did not return the same object as the original." unless orig == obj
-  rescue Exception => e
-    $failed[tag] = "#{e.class}: #{e.message}"
-  end
-end
-
-# Verify that all packages dump and load correctly and return the same Object as the original.
-capture_error('Oj:compat', $obj, 'load', 'dump') { |o| Oj.compat_load(Oj.dump(o, :mode => :compat)) }
-capture_error('JSON::Ext', $obj, 'generate', 'parse') { |o|
-  require 'json'
-  require 'json/ext'
-  JSON.generator = JSON::Ext::Generator
-  JSON.parser = JSON::Ext::Parser
-  JSON.load(JSON.generate(o))
-}
-
 if $verbose
   puts "size: #{$json.size}"
   puts "json:\n#{$json}\n"
