@@ -96,70 +96,46 @@ class Juice < Minitest::Test
     Oj.default_options = @default_options
   end
 
-=begin
-  # Depending on the order the values may have changed. The set_options sets
-  # should cover the function itself.
-  def test_get_options
-    opts = Oj.default_options()
-    assert_equal({ :indent=>0,
-                   :second_precision=>9,
-                   :circular=>false,
-                   :class_cache=>true,
-                   :auto_define=>false,
-                   :symbol_keys=>false,
-                   :bigdecimal_as_decimal=>true,
-                   :use_to_json=>true,
-                   :nilnil=>false,
-                   :allow_gc=>true,
-                   :quirks_mode=>true,
-                   :allow_invalid_unicode=>false,
-                   :float_precision=>15,
-                   :mode=>:object,
-                   :escape_mode=>:json,
-                   :time_format=>:unix_zone,
-                   :bigdecimal_load=>:auto,
-                   :create_id=>'json_class'}, opts)
-  end
-=end
   def test_set_options
     orig = Oj.default_options()
     alt ={
-      :indent=>" - ",
-      :second_precision=>5,
-      :circular=>true,
-      :class_cache=>false,
-      :auto_define=>true,
-      :symbol_keys=>true,
-      :bigdecimal_as_decimal=>false,
-      :use_to_json=>false,
-      :use_to_hash=>false,
-      :use_as_json=>false,
-      :use_raw_json=>false,
-      :nilnil=>true,
-      :empty_string=>true,
-      :allow_gc=>false,
-      :quirks_mode=>false,
-      :allow_invalid_unicode=>true,
-      :float_precision=>13,
-      :mode=>:strict,
-      :escape_mode=>:ascii,
-      :time_format=>:unix_zone,
-      :bigdecimal_load=>:float,
-      :create_id=>'classy',
-      :create_additions=>true,
-      :space=>'z',
-      :array_nl=>'a',
-      :object_nl=>'o',
-      :space_before=>'b',
-      :nan=>:huge,
-      :hash_class=>Hash,
-      :omit_nil=>false,
-      :allow_nan=>true,
-      :integer_range=>nil,
-      :array_class=>Array,
-      :ignore=>nil,
-      :trace=>true,
-      :safe=>true,
+      indent: " - ",
+      second_precision: 5,
+      circular: true,
+      class_cache: false,
+      auto_define: true,
+      symbol_keys: true,
+      bigdecimal_as_decimal: false,
+      use_to_json: false,
+      use_to_hash: false,
+      use_as_json: false,
+      use_raw_json: false,
+      nilnil: true,
+      empty_string: true,
+      allow_gc: false,
+      quirks_mode: false,
+      allow_invalid_unicode: true,
+      float_precision: 13,
+      mode: :strict,
+      escape_mode: :ascii,
+      time_format: :unix_zone,
+      bigdecimal_load: :float,
+      create_id: 'classy',
+      create_additions: true,
+      space: 'z',
+      array_nl: 'a',
+      object_nl: 'o',
+      space_before: 'b',
+      nan: :huge,
+      hash_class: Hash,
+      omit_nil: false,
+      allow_nan: true,
+      integer_range: nil,
+      array_class: Array,
+      ignore: nil,
+      ignore_under: true,
+      trace: true,
+      safe: true,
     }
     Oj.default_options = alt
     #keys = alt.keys
@@ -425,8 +401,11 @@ class Juice < Minitest::Test
   def test_time_years
     (-2020..2020).each { |year|
       s = "%04d-03-01T15:14:13Z" % [year]
-      json = Oj.dump(Time.parse(s), mode: :custom, time_format: :xmlschema)
+      json = Oj.dump(Time.parse(s), mode: :custom, time_format: :xmlschema, second_precision: -1)
       assert_equal(s, json[1..-2])
+
+      json = Oj.dump(Time.parse(s), mode: :custom, time_format: :xmlschema, second_precision: 3)
+      assert_equal(s[0..-2] + '.000Z', json[1..-2])
     }
   end
 
